Software Heritage - Archive altering facilities
===============================================

It happens for Software Heritage to record content that either should not
have been archived or should no longer be archived. ``swh-alter`` holds
the tools necessary to prune or make inaccessible content from Software
Heritage archive.
